summaryrefslogtreecommitdiff
path: root/src/jit/compiler.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/jit/compiler.hpp')
-rw-r--r--src/jit/compiler.hpp17
1 files changed, 8 insertions, 9 deletions
diff --git a/src/jit/compiler.hpp b/src/jit/compiler.hpp
index 29a79f862b..3fceff729a 100644
--- a/src/jit/compiler.hpp
+++ b/src/jit/compiler.hpp
@@ -1157,21 +1157,20 @@ inline GenTreeCall* Compiler::gtNewHelperCallNode(unsigned helper, var_types typ
// gtNewAllocObjNode: A little helper to create an object allocation node.
//
// Arguments:
// helper - Value returned by ICorJitInfo::getNewHelper
// clsHnd - Corresponding class handle
// type - Tree return type (e.g. TYP_REF)
// op1 - Node containing an address of VtablePtr
//
// Return Value:
// Returns GT_ALLOCOBJ node that will be later morphed into an
// allocation helper call or local variable allocation on the stack.
-inline GenTreeAllocObj* Compiler::gtNewAllocObjNode(unsigned int helper,
- CORINFO_CLASS_HANDLE clsHnd,
- var_types type,
- GenTree* op1)
+inline GenTreeAllocObj* Compiler::gtNewAllocObjNode(
+ unsigned int helper, bool helperHasSideEffects, CORINFO_CLASS_HANDLE clsHnd, var_types type, GenTree* op1)
{
- GenTreeAllocObj* node = new (this, GT_ALLOCOBJ) GenTreeAllocObj(type, helper, clsHnd, op1);
+ GenTreeAllocObj* node = new (this, GT_ALLOCOBJ) GenTreeAllocObj(type, helper, helperHasSideEffects, clsHnd, op1);
return node;
}
@@ -1157,21 +1157,20 @@ inline GenTreeCall* Compiler::gtNewHelperCallNode(unsigned helper, var_types typ
//
// Arguments:
-// helper - Value returned by ICorJitInfo::getNewHelper
-// clsHnd - Corresponding class handle
-// type - Tree return type (e.g. TYP_REF)
-// op1 - Node containing an address of VtablePtr
+// helper - Value returned by ICorJitInfo::getNewHelper
+// helperHasSideEffects - True iff allocation helper has side effects
+// clsHnd - Corresponding class handle
+// type - Tree return type (e.g. TYP_REF)
+// op1 - Node containing an address of VtablePtr
//
// Return Value: